Crate cu_sensor_payloads

Crate cu_sensor_payloads 

Modules

pointcloud_soa

Structs

BarometerPayload
Standardized barometer payload carrying pressure and temperature.
CuHandlePayload
CuImage
CuImageBufferFormat
CuImagePlaneLayout
ImuPayload
Standardized IMU payload carrying acceleration, angular velocity, and optional magnetometer data.
ImuWithMagPayload
Combined payload allowing optional magnetometer data.
MagnetometerPayload
Magnetometer payload split from the main IMU data for composition.
PointCloud
Standardized PointCloud. note: the derive(Soa) will generate a PointCloudSoa struct that will store the data in a SoA format. The Soa format is appropriate for early pipeline operations like changing their frame of reference. important: The ToV of the points are not assumed to be sorted.
PointCloudSoa
PointCloudSoaHandleMeta
PointCloudSoaStorage

Traits

CuHandlePayloadInit
CuHandlePayloadMeta

Type Aliases

Distance
PointCloudSoaHandle
Copper point-cloud payload stored behind a CuHandle so large clouds do not live inline on the thread stack.
Reflectivity